@@ -1,21 +1,28 @@
-// Copyright (C) 2008-2015 National ICT Australia (NICTA)
+// Copyright 2008-2016 Conrad Sanderson (http://conradsanderson.id.au)
+// Copyright 2008-2016 National ICT Australia (NICTA)
 // 
-// This Source Code Form is subject to the terms of the Mozilla Public
-// License, v. 2.0. If a copy of the MPL was not distributed with this
-// file, You can obtain one at http://mozilla.org/MPL/2.0/.
-// -------------------------------------------------------------------
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+// http://www.apache.org/licenses/LICENSE-2.0
 // 
-// Written by Conrad Sanderson - http://conradsanderson.id.au
-// Written by James Sanders
-// Written by Eric Jon Sundstrom
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+// ------------------------------------------------------------------------
 
 
 
 #ifdef ARMA_USE_LAPACK
 
+#if defined(dgetrf) || defined(DGETRF)
+  #pragma message ("WARNING: detected possible interference with definitions of LAPACK functions;")
+  #pragma message ("WARNING: include the armadillo header before any other header as a workaround")
+#endif
 
 #if !defined(ARMA_BLAS_CAPITALS)
-  
   #define arma_sgetrf sgetrf
   #define arma_dgetrf dgetrf
   #define arma_cgetrf cgetrf
@@ -59,6 +66,11 @@
   #define arma_cpotrf cpotrf
   #define arma_zpotrf zpotrf
   
+  #define arma_spbtrf spbtrf
+  #define arma_dpbtrf dpbtrf
+  #define arma_cpbtrf cpbtrf
+  #define arma_zpbtrf zpbtrf
+  
   #define arma_spotri spotri
   #define arma_dpotri dpotri
   #define arma_cpotri cpotri
@@ -111,6 +123,26 @@
   #define arma_ctrtrs ctrtrs
   #define arma_ztrtrs ztrtrs
 
+  #define arma_sgbsv  sgbsv
+  #define arma_dgbsv  dgbsv
+  #define arma_cgbsv  cgbsv
+  #define arma_zgbsv  zgbsv
+  
+  #define arma_sgbsvx sgbsvx
+  #define arma_dgbsvx dgbsvx
+  #define arma_cgbsvx cgbsvx
+  #define arma_zgbsvx zgbsvx
+  
+  #define arma_sgtsv  sgtsv
+  #define arma_dgtsv  dgtsv
+  #define arma_cgtsv  cgtsv
+  #define arma_zgtsv  zgtsv
+  
+  #define arma_sgtsvx sgtsvx
+  #define arma_dgtsvx dgtsvx
+  #define arma_cgtsvx cgtsvx
+  #define arma_zgtsvx zgtsvx
+  
   #define arma_sgees  sgees
   #define arma_dgees  dgees
   #define arma_cgees  cgees
@@ -170,6 +202,11 @@
   #define arma_slarnv slarnv
   #define arma_dlarnv dlarnv
   
+  #define arma_sgehrd sgehrd
+  #define arma_dgehrd dgehrd
+  #define arma_cgehrd cgehrd
+  #define arma_zgehrd zgehrd
+  
 #else
   
   #define arma_sgetrf SGETRF
@@ -215,6 +252,11 @@
   #define arma_cpotrf CPOTRF
   #define arma_zpotrf ZPOTRF
   
+  #define arma_spbtrf SPBTRF
+  #define arma_dpbtrf DPBTRF
+  #define arma_cpbtrf CPBTRF
+  #define arma_zpbtrf ZPBTRF
+  
   #define arma_spotri SPOTRI
   #define arma_dpotri DPOTRI
   #define arma_cpotri CPOTRI
@@ -267,6 +309,26 @@
   #define arma_ctrtrs CTRTRS
   #define arma_ztrtrs ZTRTRS
 
+  #define arma_sgbsv  SGBSV
+  #define arma_dgbsv  DGBSV
+  #define arma_cgbsv  CGBSV
+  #define arma_zgbsv  ZGBSV
+  
+  #define arma_sgbsvx SGBSVX
+  #define arma_dgbsvx DGBSVX
+  #define arma_cgbsvx CGBSVX
+  #define arma_zgbsvx ZGBSVX
+  
+  #define arma_sgtsv  SGTSV
+  #define arma_dgtsv  DGTSV
+  #define arma_cgtsv  CGTSV
+  #define arma_zgtsv  ZGTSV
+  
+  #define arma_sgtsvx SGTSVX
+  #define arma_dgtsvx DGTSVX
+  #define arma_cgtsvx CGTSVX
+  #define arma_zgtsvx ZGTSVX
+  
   #define arma_sgees  SGEES
   #define arma_dgees  DGEES
   #define arma_cgees  CGEES
@@ -325,6 +387,11 @@
   
   #define arma_slarnv SLARNV
   #define arma_dlarnv DLARNV
+
+  #define arma_sgehrd SGEHRD
+  #define arma_dgehrd DGEHRD
+  #define arma_cgehrd CGEHRD
+  #define arma_zgehrd ZGEHRD
   
 #endif
 
@@ -388,6 +455,12 @@ extern "C"
   void arma_fortran(arma_cpotrf)(char* uplo, blas_int* n,   void* a, blas_int* lda, blas_int* info);
   void arma_fortran(arma_zpotrf)(char* uplo, blas_int* n,   void* a, blas_int* lda, blas_int* info);
   
+  // Cholesky decomposition (band matrices)
+  void arma_fortran(arma_spbtrf)(char* uplo, blas_int* n, blas_int* kd,  float* ab, blas_int* ldab, blas_int* info);
+  void arma_fortran(arma_dpbtrf)(char* uplo, blas_int* n, blas_int* kd, double* ab, blas_int* ldab, blas_int* info);
+  void arma_fortran(arma_cpbtrf)(char* uplo, blas_int* n, blas_int* kd,   void* ab, blas_int* ldab, blas_int* info);
+  void arma_fortran(arma_zpbtrf)(char* uplo, blas_int* n, blas_int* kd,   void* ab, blas_int* ldab, blas_int* info);
+  
   // matrix inversion (using Cholesky decomposition result)
   void arma_fortran(arma_spotri)(char* uplo, blas_int* n,  float* a, blas_int* lda, blas_int* info);
   void arma_fortran(arma_dpotri)(char* uplo, blas_int* n, double* a, blas_int* lda, blas_int* info);
@@ -458,6 +531,34 @@ extern "C"
   void arma_fortran(arma_ctrtrs)(char* uplo, char* trans, char* diag, blas_int* n, blas_int* nrhs, const void*   a, blas_int* lda, void*   b, blas_int* ldb, blas_int* info);
   void arma_fortran(arma_ztrtrs)(char* uplo, char* trans, char* diag, blas_int* n, blas_int* nrhs, const void*   a, blas_int* lda, void*   b, blas_int* ldb, blas_int* info);
   
+  // solve system of linear equations (general band matrix)
+  void arma_fortran(arma_sgbsv)(blas_int* n, blas_int* kl, blas_int* ku, blas_int* nrhs,  float* ab, blas_int* ldab, blas_int* ipiv,  float* b, blas_int* ldb, blas_int* info);
+  void arma_fortran(arma_dgbsv)(blas_int* n, blas_int* kl, blas_int* ku, blas_int* nrhs, double* ab, blas_int* ldab, blas_int* ipiv, double* b, blas_int* ldb, blas_int* info);
+  void arma_fortran(arma_cgbsv)(blas_int* n, blas_int* kl, blas_int* ku, blas_int* nrhs,   void* ab, blas_int* ldab, blas_int* ipiv,   void* b, blas_int* ldb, blas_int* info);
+  void arma_fortran(arma_zgbsv)(blas_int* n, blas_int* kl, blas_int* ku, blas_int* nrhs,   void* ab, blas_int* ldab, blas_int* ipiv,   void* b, blas_int* ldb, blas_int* info);
+  
+  // solve system of linear equations (general band matrix, advanced form, real matrices)
+  void arma_fortran(arma_sgbsvx)(char* fact, char* trans, blas_int* n, blas_int* kl, blas_int* ku, blas_int* nrhs,  float* ab, blas_int* ldab,  float* afb, blas_int* ldafb, blas_int* ipiv, char* equed,  float* r,  float* c,  float* b, blas_int* ldb,  float* x, blas_int* ldx,  float* rcond,  float* ferr,  float* berr,  float* work, blas_int* iwork, blas_int* info);
+  void arma_fortran(arma_dgbsvx)(char* fact, char* trans, blas_int* n, blas_int* kl, blas_int* ku, blas_int* nrhs, double* ab, blas_int* ldab, double* afb, blas_int* ldafb, blas_int* ipiv, char* equed, double* r, double* c, double* b, blas_int* ldb, double* x, blas_int* ldx, double* rcond, double* ferr, double* berr, double* work, blas_int* iwork, blas_int* info);
+  
+  // solve system of linear equations (general band matrix, advanced form, complex matrices)
+  void arma_fortran(arma_cgbsvx)(char* fact, char* trans, blas_int* n, blas_int* kl, blas_int* ku, blas_int* nrhs, void* ab, blas_int* ldab, void* afb, blas_int* ldafb, blas_int* ipiv, char* equed,  float* r,  float* c, void* b, blas_int* ldb, void* x, blas_int* ldx,  float* rcond,  float* ferr,  float* berr, void* work,  float* rwork, blas_int* info);
+  void arma_fortran(arma_zgbsvx)(char* fact, char* trans, blas_int* n, blas_int* kl, blas_int* ku, blas_int* nrhs, void* ab, blas_int* ldab, void* afb, blas_int* ldafb, blas_int* ipiv, char* equed, double* r, double* c, void* b, blas_int* ldb, void* x, blas_int* ldx, double* rcond, double* ferr, double* berr, void* work, double* rwork, blas_int* info);
+  
+  // solve system of linear equations (tridiagonal band matrix)
+  void arma_fortran(arma_sgtsv)(blas_int* n, blas_int* nrhs,  float* dl,  float* d,  float* du,  float* b, blas_int* ldb, blas_int* info);
+  void arma_fortran(arma_dgtsv)(blas_int* n, blas_int* nrhs, double* dl, double* d, double* du, double* b, blas_int* ldb, blas_int* info);
+  void arma_fortran(arma_cgtsv)(blas_int* n, blas_int* nrhs,   void* dl,   void* d,   void* du,   void* b, blas_int* ldb, blas_int* info);
+  void arma_fortran(arma_zgtsv)(blas_int* n, blas_int* nrhs,   void* dl,   void* d,   void* du,   void* b, blas_int* ldb, blas_int* info);
+  
+  // solve system of linear equations (tridiagonal band matrix, advaned form, real matrices)
+  void arma_fortran(arma_sgtsvx)(char* fact, char* trans, blas_int* n, blas_int* nrhs,  float* dl,  float* d,  float* du,  float* dlf,  float* df,  float* duf,  float* du2, blas_int* ipiv,  float* b, blas_int* ldb,  float* x, blas_int* ldx,  float* rcond,  float* ferr,  float* berr,  float* work, blas_int* iwork, blas_int* info);
+  void arma_fortran(arma_dgtsvx)(char* fact, char* trans, blas_int* n, blas_int* nrhs, double* dl, double* d, double* du, double* dlf, double* df, double* duf, double* du2, blas_int* ipiv, double* b, blas_int* ldb, double* x, blas_int* ldx, double* rcond, double* ferr, double* berr, double* work, blas_int* iwork, blas_int* info);
+  
+  // solve system of linear equations (tridiagonal band matrix, advaned form, complex matrices)
+  void arma_fortran(arma_cgtsvx)(char* fact, char* trans, blas_int* n, blas_int* nrhs, void* dl, void* d, void* du, void* dlf, void* df, void* duf, void* du2, blas_int* ipiv, void* b, blas_int* ldb, void* x, blas_int* ldx,  float* rcond,  float* ferr,  float* berr, void* work,  float* rwork, blas_int* info);
+  void arma_fortran(arma_zgtsvx)(char* fact, char* trans, blas_int* n, blas_int* nrhs, void* dl, void* d, void* du, void* dlf, void* df, void* duf, void* du2, blas_int* ipiv, void* b, blas_int* ldb, void* x, blas_int* ldx, double* rcond, double* ferr, double* berr, void* work, double* rwork, blas_int* info);
+  
   // Schur decomposition (real matrices)
   void arma_fortran(arma_sgees)(char* jobvs, char* sort, void* select, blas_int* n, float*  a, blas_int* lda, blas_int* sdim, float*  wr, float*  wi, float*  vs, blas_int* ldvs, float*  work, blas_int* lwork, blas_int* bwork, blas_int* info);
   void arma_fortran(arma_dgees)(char* jobvs, char* sort, void* select, blas_int* n, double* a, blas_int* lda, blas_int* sdim, double* wr, double* wi, double* vs, blas_int* ldvs, double* work, blas_int* lwork, blas_int* bwork, blas_int* info);
@@ -534,6 +635,12 @@ extern "C"
   // generate a vector of random numbers
   void arma_fortran(arma_slarnv)(blas_int* idist, blas_int* iseed, blas_int* n, float*  x);
   void arma_fortran(arma_dlarnv)(blas_int* idist, blas_int* iseed, blas_int* n, double* x);
+  
+  // hessenberg decomposition
+  void arma_fortran(arma_sgehrd)(blas_int* n, blas_int* ilo, blas_int* ihi, float*  a, blas_int* lda, float*  tao, float*  work, blas_int* lwork, blas_int* info);
+  void arma_fortran(arma_dgehrd)(blas_int* n, blas_int* ilo, blas_int* ihi, double* a, blas_int* lda, double* tao, double* work, blas_int* lwork, blas_int* info);
+  void arma_fortran(arma_cgehrd)(blas_int* n, blas_int* ilo, blas_int* ihi, void*   a, blas_int* lda, void*   tao, void*   work, blas_int* lwork, blas_int* info);
+  void arma_fortran(arma_zgehrd)(blas_int* n, blas_int* ilo, blas_int* ihi, void*   a, blas_int* lda, void*   tao, void*   work, blas_int* lwork, blas_int* info);
   }
 
 
