@@ -1,11 +1,17 @@
-// Copyright (C) 2010-2015 National ICT Australia (NICTA)
+// Copyright 2008-2016 Conrad Sanderson (http://conradsanderson.id.au)
+// Copyright 2008-2016 National ICT Australia (NICTA)
 // 
-// This Source Code Form is subject to the terms of the Mozilla Public
-// License, v. 2.0. If a copy of the MPL was not distributed with this
-// file, You can obtain one at http://mozilla.org/MPL/2.0/.
-// -------------------------------------------------------------------
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+// http://www.apache.org/licenses/LICENSE-2.0
 // 
-// Written by Conrad Sanderson - http://conradsanderson.id.au
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+// ------------------------------------------------------------------------
 
 
 //! \addtogroup strip
@@ -18,7 +24,7 @@ struct strip_diagmat
   {
   typedef T1 stored_type;
   
-  arma_hot inline
+  inline
   strip_diagmat(const T1& X)
     : M(X)
     {
@@ -37,7 +43,7 @@ struct strip_diagmat< Op<T1, op_diagmat> >
   {
   typedef T1 stored_type;
   
-  arma_hot inline
+  inline
   strip_diagmat(const Op<T1, op_diagmat>& X)
     : M(X.m)
     {
@@ -56,7 +62,7 @@ struct strip_inv
   {
   typedef T1 stored_type;
   
-  arma_hot inline
+  inline
   strip_inv(const T1& X)
     : M(X)
     {
@@ -75,7 +81,7 @@ struct strip_inv< Op<T1, op_inv> >
   {
   typedef T1 stored_type;
   
-  arma_hot inline
+  inline
   strip_inv(const Op<T1, op_inv>& X)
     : M(X.m)
     {
@@ -94,7 +100,7 @@ struct strip_inv< Op<T1, op_inv_sympd> >
   {
   typedef T1 stored_type;
   
-  arma_hot inline
+  inline
   strip_inv(const Op<T1, op_inv_sympd>& X)
     : M(X.m)
     {
